#include "client_common.hpp"
#include <random>
std::default_random_engine gen(std::random_device{}());

int main(int argc, char **argv) {
    if (argc != 3) {
        fprintf(stderr, "Usage: %s <ip> <port>\n", argv[0]);
        return 1;
    }

    addrinfo *resolved, hints = {.ai_family = AF_INET, .ai_protocol = IPPROTO_UDP};
    if (int err = getaddrinfo(argv[1], argv[2], &hints, &resolved)) {
        fprintf(stderr, "Resolving address failed: %s\n", gai_strerror(err));
        return 1;
    }

    int sock = socket(resolved->ai_family, resolved->ai_socktype, resolved->ai_protocol);

    std::uniform_int_distribution<int> dist(7, 15);

    for (int i = 0; i < 20; i++) {
        size_t msgLen = dist(gen);
        char buf[msgLen];
        int numLen = sprintf(buf, "%d", i);
        memset(buf + numLen, '.', msgLen - numLen);

        sendto(sock, buf, msgLen, 0, resolved->ai_addr, resolved->ai_addrlen);
    }

    freeaddrinfo(resolved);
    close(sock);
    return 0;
}
